@@ -123,6 +123,20 @@
   MN_CONF_MAIL_SUMMARY_POPUP_OFFSET_NAMESPACE "/vertical"
 #define MN_CONF_MAIL_SUMMARY_POPUP_ONLY_RECENT \
   MN_CONF_MAIL_SUMMARY_POPUP_NAMESPACE "/only-recent"
+#define MN_CONF_MAIL_SUMMARY_POPUP_FONTS_NAMESPACE \
+  MN_CONF_MAIL_SUMMARY_POPUP_NAMESPACE "/fonts"
+#define MN_CONF_MAIL_SUMMARY_POPUP_FONTS_TITLE_NAMESPACE \
+  MN_CONF_MAIL_SUMMARY_POPUP_FONTS_NAMESPACE "/title"
+#define MN_CONF_MAIL_SUMMARY_POPUP_FONTS_TITLE_ENABLED \
+  MN_CONF_MAIL_SUMMARY_POPUP_FONTS_TITLE_NAMESPACE "/enabled"
+#define MN_CONF_MAIL_SUMMARY_POPUP_FONTS_TITLE_FONT \
+  MN_CONF_MAIL_SUMMARY_POPUP_FONTS_TITLE_NAMESPACE "/font"
+#define MN_CONF_MAIL_SUMMARY_POPUP_FONTS_CONTENTS_NAMESPACE \
+  MN_CONF_MAIL_SUMMARY_POPUP_FONTS_NAMESPACE "/contents"
+#define MN_CONF_MAIL_SUMMARY_POPUP_FONTS_CONTENTS_ENABLED \
+  MN_CONF_MAIL_SUMMARY_POPUP_FONTS_CONTENTS_NAMESPACE "/enabled"
+#define MN_CONF_MAIL_SUMMARY_POPUP_FONTS_CONTENTS_FONT \
+  MN_CONF_MAIL_SUMMARY_POPUP_FONTS_CONTENTS_NAMESPACE "/font"
 #define MN_CONF_DOUBLE_CLICK_ACTION \
   MN_CONF_NAMESPACE "/double-click-action"
 
